import { OnInit, ElementRef, EventEmitter } from '@angular/core';
import { LoggerService } from '../service/logger.service';
import { PrettyPrinterService } from "../service/pretty-printer.service";
import { CopierService } from "../service/copier.service";
import { MatSnackBar } from '@angular/material';
/**
 * Formatted Code Block
 *
 * Pretty renders a code block, used by code-example and code-tabs embedded components.
 *
 * Example usage:
 *
 * <app-code-core
 *   [language]="ts"
 *   [linenums]="true">
 * </app-code-core>
 *
 * Renders code provided through the `updateCode` method.
 */
export declare class CoreComponent implements OnInit {
    private snackbar;
    private pretty;
    private copier;
    private logger;
    /** Code that should be formatted with current inputs and displayed in the view. */
    private _code;
    code: string;
    private codeText;
    /** Language to render the code (e.g. javascript, dart, typescript). */
    language: string;
    /**
     * Whether to display line numbers:
     *  - If false: hide
     *  - If true: show
     *  - If number: show but start at that number
     */
    linenums: boolean | number | string;
    codeFormatted: EventEmitter<void>;
    /** The element in the template that will display the formatted code. */
    codeContainer: ElementRef;
    constructor(snackbar: MatSnackBar, pretty: PrettyPrinterService, copier: CopierService, logger: LoggerService);
    ngOnInit(): void;
    ngOnChanges(): void;
    /** Sets the message showing that the code could not be found. */
    private showMissingCodeMessage;
    private formatDisplayedCode;
    /** let the code string left indent until one of the code line touch the left side without space */
    private leftAlign;
    /** Sets the innerHTML of the code container to the provided code string. */
    private setCodeHtml;
    /** Gets the textContent of the displayed code element. */
    private getCodeText;
    /** Copies the code snippet to the user's clipboard. */
    doCopy(): void;
    /** Gets the calculated value of linenums (boolean/number). */
    getLinenums(code: string): number | boolean;
    open(): void;
}
